@@ -1,17 +1,18 @@
 """Decorators for applying rich exceptions."""
+from wrapper import wrap_fixture_with_exception
 
 __all__ = [
     'broken_inherited_tests',
     'broken_test',
     'irrelevant_test',
-    'test_subject_not_implemented',
+    'unimplemented_subject_under_test',
 ]
 
 
 from _errors import BrokenTestException
 from _errors import IrrelevantTestException
 from nose.tools import nottest
-from rhinoplasty.wrapper import wrap_test_fixture
+from rhinoplasty.wrapper import wrap_test_function
 import inspect
 
 
@@ -33,7 +34,7 @@ def broken_test(arg):
         arg_is_fixture = False
     
     # Get the wrapper function for the test fixture
-    func = _decorate_fixture(description, BrokenTestException)
+    func = wrap_fixture_with_exception(BrokenTestException(description))
     
     # Decorate the fixture
     if arg_is_fixture:
@@ -73,7 +74,7 @@ def broken_inherited_tests(reason, *functions):
             
             # Create a replacement function
             @broken_test(reason)
-            @wrap_test_fixture(original_function)
+            @wrap_test_function(original_function)
             def new_method(self):
                 bound_function = original_function.__get__(self, TestClass)
                 bound_function()
@@ -99,7 +100,7 @@ def irrelevant_test(condition, description):
     
     if condition:
         # Skip the test fixture
-        decorate = _decorate_fixture(description, IrrelevantTestException)
+        decorate = wrap_fixture_with_exception(IrrelevantTestException(description))
     else:
         # Leave the decorated fixture unchanged.
         def decorate(fixture):
@@ -109,9 +110,9 @@ def irrelevant_test(condition, description):
 
 
 @nottest
-def test_subject_not_implemented(arg):
+def unimplemented_subject_under_test(arg):
     """Decorator to mark that this test function or test class is broken
-    because functionality of the subject under test has not been implemented.
+    because the functionality under test has not been implemented.
     
     Alternatively, the test may raise NotImplementedError directly, and it will
     be treated exactly the same.
@@ -130,7 +131,7 @@ def test_subject_not_implemented(arg):
         arg_is_fixture = False
     
     # Get the wrapper function for the test fixture
-    func = _decorate_fixture(description, NotImplementedError)
+    func = wrap_fixture_with_exception(NotImplementedError(description))
     
     # Decorate the fixture
     if arg_is_fixture:
@@ -138,36 +139,4 @@ def test_subject_not_implemented(arg):
     return func
 
 
-@nottest
-def _decorate_fixture(description, ExceptionClass):
-    """Get a decorator wrapper function for a test fixture, that will raise an
-    exception when the tests are run.
-    
-    @param description: Description for why the decorated object is skipped.
-    @param ExceptionClass: The exception class to raise.
-    """
-    #TODO should we move this function to the wrapper module?
-    def decorate(fixture):
-        if inspect.isclass(fixture):
-            # Create a replacement class that raises an appropriate exception
-            @wrap_test_fixture(fixture)
-            class ClassWrapper(object):
-                def test_suite_raises_exception(self):
-                    raise ExceptionClass(description)
-                test_suite_raises_exception.__doc__ = fixture.__doc__
-            
-            return ClassWrapper
-                    
-        elif callable(fixture):
-            # Create a replacement function that raises an appropriate exception
-            
-            #noinspection PyUnusedLocal
-            @wrap_test_fixture(fixture)
-            def function_wrapper(*args):
-                """Replaces the failing test and unconditionally raises an exception."""
-                raise ExceptionClass(description)
-            return function_wrapper
-        else:
-            raise ValueError("Decorated object is neither a class nor a function")
-    
-    return decorate
+
